@@ -7,11 +7,12 @@ test_that("mm returns an object of class MMLong", {
   time   = unlist( sapply( as.list(nclust), function(ZZ) seq(ZZ)-1 ) )
   data   = data.frame(id, time, Xe)
   data   = data[order(data$id, data$time),]
-  newdat = GenBinaryY(mean.formula=~time*Xe, t.formula=~1,
+  Y      = GenBinaryY(mean.formula=~time*Xe, t.formula=~1,
                       beta=c(-2.5, 0.25, 0.25, 0.1),
-                      gamma=1, id=id, data=data, q=20, Yname = "binY")
+                      gamma=1, id=id, data=data, q=20)
+  newdat = data.frame(data, Y = Y)
 
-  fit <- mm(binY~time*Xe, t.formula=~1, data=newdat, id=id, step.max=4, verbose=FALSE)
+  fit <- mm(Y~time*Xe, t.formula=~1, data=newdat, id=id, step.max=4, verbose=FALSE)
 
   expect_equal(class(fit), "MMLong")
 
@@ -26,11 +27,12 @@ test_that("Inputs of mm are correct", {
   time   = unlist( sapply( as.list(nclust), function(ZZ) seq(ZZ)-1 ) )
   data   = data.frame(id, time, Xe)
   data   = data[order(data$id, data$time),]
-  newdat = GenBinaryY(mean.formula=~time*Xe, t.formula=~1,
+  Y      = GenBinaryY(mean.formula=~time*Xe, t.formula=~1,
                       beta=c(-2.5, 0.25, 0.25, 0.1),
-                      gamma=1, id=id, data=data, q=20, Yname = "binY")
+                      gamma=1, id=id, data=data, q=20)
+  newdat = data.frame(data, Y = Y)
 
-  expect_error(mm(binY~time*Xe, data=newdat,
+  expect_error(mm(Y~time*Xe, data=newdat,
                     id=id, step.max=4, verbose=FALSE))
 
 })
